**    ModelEco : MODELling in mathematical programming for the ECOnomic analysis of agriculture    **

*-----------------------------------------------------------------------------*
$Ontext
Name             AnimalFeed
Sequence         1 - Introduction to mathematical programming using GAMS
Type             LP
GAMS language    Introduction to the GAMS language
Description      Simple linear programming formulation exercice
                 First linear programming model
" A feed company produces concentrates intended for cattle using different types of ingredients:
protein crops (peas), cereals crops (maize) and cattle cake (soya-bean).
The concentrates obtained must have a minimum guaranteed content of TNM (Total Nitrogenous Matter)
and fat as well as maximum mineral matter and crude fibre contents

Minimum content        TNM (g/kg)                      Fat (g/kg)
Concentrate                  200                           25
Maximum content        Mineral matter (g/kg)        Crude fibre (g/kg)
Concentrate                  70                            65

The content of each of these components is known for every ingredient.

Content         TNM (g/kg)        Fat (g/kg)        Mineral Matter (g/kg)        Crude fibre (g/kg)
Maize               81                37                     12                       22
Peas               207                10                     30                       52
Soya-bean cakes    453                19                     64                       60

The cost of maize is 148/T, that of peas 195/T and soya-bean cakes 355/T.
The company wants to find the optimal formulation of a kilogram of concentrate
in order to respect the guaranteed content, while minimizing production costs. "


$Offtext
*-----------------------------------------------------------------------------*


*----------                         DECLARATION                     ----------*
SETS
I ingredients / maize, peas, soya-bean/
;

*----------                          DATA                           ----------*
SCALAR
CMin1    /200/
CMin2    /25/
CMax3    /70/
CMax4    /65/
;

*----------                         MODEL                           ----------*
PARAMETERS
KC1(I) known TNM content in g per kg
/maize        81
peas         207
soya-bean    453
/
KC2(I) known fat content in g per kg
/maize        37
peas          10
soya-bean     19
/
KC3(I) known mineral matter content in g per kg
/maize        12
peas          30
soya-bean     64
/
KC4(I)  known crude fibre content in g per kg
/maize        22
peas          52
soya-bean     60
/
;

PARAMETERS
PC(I) ingredient prices in euros per tonne
/maize 0.148, peas 0.195, soya-bean 0.355/
;

POSITIVE VARIABLE
X(I) quantity of each ingredient per kilo of concentrate
;

VARIABLE
C total cost
;

EQUATIONS
OBJECTIVE
C_TNC
C_FAT
C_mineral
C_crudefibre
WEIGHT
;

OBJECTIVE..   sum(I, PC(I)*X(I)) =e= C ;
C_TNC..       sum(I, KC1(I)*X(I)) =g= CMin1 ;
C_FAT..       sum(I, KC2(I)*X(I)) =g= CMin2 ;
C_mineral..   sum(I, KC3(I)*X(I)) =l= CMax3 ;
C_crudefibre..sum(I, KC4(I)*X(I)) =l= CMax4 ;
WEIGHT..      sum(I, X(I)) =e= 1 ;

MODEL concentrates /all/
;

*----------                        SOLUTION                         ----------*
SOLVE concentrates using LP minimizing C
;
